#
# spec file for package cozy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid com.github.geigi.cozy
Name:           cozy
Version:        1.3.0
Release:        1.1
Summary:        Audio Book Player
License:        GPL-3.0-only
URL:            https://github.com/geigi/cozy
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-distro
BuildRequires:  python3-gobject
BuildRequires:  python3-mutagen
BuildRequires:  python3-peewee
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1) >= 1.5.0
BuildRequires:  pkgconfig(python3)
Requires:       python3-distro
Requires:       python3-injector
Requires:       python3-mutagen
Requires:       python3-peewee
Requires:       python3-pytz
Requires:       python3-requests
Recommends:     gstreamer-plugins-base
Recommends:     gstreamer-plugins-good
Recommends:     gstreamer-plugins-ugly
Provides:       %{appid} = %{version}
Obsoletes:      %{appid} < %{version}
BuildArch:      noarch

%description
Play and organize your audio book collection.

%lang_package

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}

%files
%license LICENSE
%doc AUTHORS.md README.md
%attr(0755,root,root) %{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/metainfo/%{appid}.appdata.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/icons/hicolor/*/apps/%{appid}{.Devel,-symbolic}.svg
%{_datadir}/icons/hicolor/*/actions/*.svg
%{_datadir}/%{appid}
%{python3_sitelib}/%{name}

%files lang -f %{appid}.lang

%changelog
* Sun Nov 17 2024 Richard Rahl <rrahl0@opensuse.org>
- update spec file for Leap 16.0:
  * rework the BuildRequires, as the software moved from granite to gtk directly
  * remove %%suse_update_desktop_file
  * use autosetup
* Fri May 10 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Fix build by adding missing dependency and using correct filename
* Sat Mar 23 2024 Julian Geywitz <suse@geigi.de>
- Update to 1.3.0
  After almost two years, a new version of Cozy is finally here! This release brings an updated user interface along with numerous bug fixes and improved performance.
  The user interface has been ported to GTK4 and Libadwaita. Thus, Cozy benefits from the new style sheet, automatic dark mode, and utilizes the latest and greatest UI elements throughout the application. Many thanks to Benedek Dévényi (@rdbende) and @grahamvh!
  * Improved mobile support
  * Smaller visual refinements to match the state of the art of GNOME apps
  * Dozens of bug fixes and performance improvements
  * Significant cleanup and improvements to the codebase
  * As always, updated translations thanks to all translators!
* Tue Jan 10 2023 Fabian Vogt <fvogt@suse.com>
- Drop unnecessary python3-magic dependency
* Sun Aug 21 2022 Julian Geywitz <suse@geigi.de>
- Update to 1.2.1
  * Support for GTK style manager (thanks A6GibKm)
  * Use natural sorting for chapter titles
  * As always, updated translations thanks to all the translators!
* Sat Jan  8 2022 Julian Geywitz <suse@geigi.de>
- Update to 1.2.0
  * Redesigned preference window
  * Preferences can now be searched
  * Fix: position slider did not update the time correctly after an import scan
  * Fix: after an import scan the library did not display the currently playing book correctly
  * Multiple small bug fixes
  * As always, updated translations thanks to all of the translators!
* Fri Aug 20 2021 Julian Geywitz <suse@geigi.de>
- Update to 1.1.2
  * Fix: in version 1.1.1 the mobile library switcher was not displayed when Cozy started with a narrow window
  * Display an error banner if an error occurs while importing new files
  * The audiobook directory selector in the empty state has been replaced by a button to allow a narrow window even with long directory names
  * Fix: multiple small UI issues
  * Fix: the welcome screen now works properly on a mobile device
  * Fix: don't display the mobile library switcher when no files are imported
  * Fix: in the book detail view the pause icon for a chapter remained even when the next chapter already started playing
  * As always, updated translations thanks to all of the translators!
* Fri Aug 20 2021 Julian Geywitz <suse@geigi.de>
- Update to 1.1.1
  * Display an error banner if an error occurs while importing new files
  * The audiobook directory selector in the empty state has been replaced by a button to allow a narrow window even with long directory names
  * Fix: multiple small UI issues
  * Fix: the welcome screen now works properly on a mobile device
  * Fix: don't display the mobile library switcher when no files are imported
  * Fix: in the book detail view the pause icon for a chapter remained even when the next chapter already started playing
  * As always, updated translations thanks to all of the translators!
* Sat Aug  7 2021 Julian Geywitz <suse@geigi.de>
- Update to 1.1.0
  * Redesigned library
  * Redesigned start screen
  * Redesigned book detail screen
  * Responsive design for the main window
  * Introducing a welcome screen for new installations
  * Fix: a rare bug where Cozy's volume was muted at first start
  * Fix: long book names or author names will be truncated properly
  * As always, updated translations thanks to all of the translators!
* Wed Jul 28 2021 Julian Geywitz <suse@geigi.de>
- Update to 1.0.4
  * Chapters in the book detail view will now be loaded lazily (thanks chris-kobrzak!)
  * Books with a single chapter don't display a chapter number anymore (thanks chris-kobrzak!)
  * Fix: Locals in What's new in Cozy screen (thanks alyssais!)
  * Fix: Catch an error that could occur when a book stops
  * Small performance improvements
  * As always, updated translations thanks to all of the translators!
* Fri Jun  4 2021 Julian Geywitz <suse@geigi.de>
- Update to 1.0.3
  * When an issue occurs during playback the error message is displayed to the user
  * Fix: Importing media without tags now properly decodes the file name as chapter name (thanks chris-kobrzak!)
  * Fix: Ensure that always a default storage location is present
  * Fix: During import an error could occur which stopped the import
  * Fix: During the database migration an error could occur
  * As always, updated translations thanks to all of the translators!
* Mon May 31 2021 Julian Geywitz <suse@geigi.de>
- Update to 1.0.2
  * When copying files to the audiobook library goes wrong, the user is now informed with the error
  * Fix: Possible error while displaying offline cache copy progress
  * Fix: When changing the audiobook location or selecting a file in the file not found dialog an unexpected error could occur
  * Fix: Removing a storage dir in settings did not work
  * Fix: Removing a book from the library did sometimes not work
  * As always, updated translations thanks to all of the translators!
* Sun May 30 2021 Julian Geywitz <suse@geigi.de>
- Update to 1.0.1
  * A long awaited feature has finally arrived: Chapter support for m4b files.
  * Books with inconsistent spelling are now grouped into a single book (thanks chris-kobrzak!).
  * Improved reliability of restoring the previous playback position.
  * Fix: clicking on a currently playing chapter did not pause the chapter as expected.
  * As always, updated translations thanks to all of the translators!
* Sun May 30 2021 Julian Geywitz <suse@geigi.de>
- Update to 1.0.0
  * A long awaited feature has finally arrived: Chapter support for m4b files.
  * Books with inconsistent spelling are now grouped into a single book (thanks chris-kobrzak!).
  * Improved reliability of restoring the previous playback position.
  * Fix: clicking on a currently playing chapter did not pause the chapter as expected.
  * As always, updated translations thanks to all of the translators!
* Sun May  9 2021 Julian Geywitz <suse@geigi.de>
- Update to 0.9.5
  * Fix: Playback speed sometimes was not set correctly when a chapter changed
  * Fix: Changing the playback position with customized playback speed did jump to a wrong position
  * Fix: Startup failed if the artwork cache did contain a broken file
  * As always, updated translations thanks to all of the translators!
* Sat Apr 24 2021 Julian Geywitz <suse@geigi.de>
- Update to 0.9.4
  * Fix: Startup failed if the last played file could not be found
  * Fix: Startup failed if the last played book does not exist anymore
  * Fix: An error which could occur when removing a storage location
  * Some additional minor fixes
  * As always, updated translations thanks to all of the translators!
* Wed Apr 21 2021 Julian Geywitz <suse@geigi.de>
- Update to 0.9.3
  * Add a rewind button to the titlebar
  * The rewind and forward duration can now be customized in the settings
  * Fix: Prevent standby during playback
  * Fix: Possible crash during startup with enabled 30 seconds rewind feature
  * Fix: Adding a new storage location could lead to an internal error which might show in strange behavior
  * As always, updated translations thanks to all of the translators!
* Wed Apr 21 2021 Julian Geywitz <suse@geigi.de>
- Update to 0.9.3
  * Add a rewind button to the titlebar
  * The rewind and forward duration can now be customized in the settings
  * Fix: Prevent standby during playback
  * Fix: Possible crash during startup with enabled 30 seconds rewind feature
  * Fix: Adding a new storage location could lead to an internal error which might show in strange behavior
  * As always, updated translations thanks to all of the translators!
* Mon Apr 19 2021 Julian Geywitz <suse@geigi.de>
- Update to 0.9.2
  * Audiobooks are not removed from your library automatically anymore when the files cannot be found.
  * The download option will be enabled for audiobooks on removable or network drives automatically for each new storage location you add.
  * Unavailable books (books where a file can't be found) can now be opened to display the book detail view. They will be flagged with a little unavailable tag
  * Under the hood improvements in the media importer
  * Media playback is rewritten from ground up. It's far more stable than before.
  * Fix: When a different system language than English is used Cozy created two folders in the users home directory on the first startup, a translated and a English one. Now only the translated folder will be created.
  * Fix: A wrong mouse pointer was displayed with some pointer themes
  * Fix: A memory leak in the importer
  * Fix: The playback speed of a book was not remembered correctly
  * Fix: The desktop integration did not respect the switch author and reader setting
  * Fix: Setting the Playback speed did not work in v0.9
  * Many other small fixes that make Cozy more reliable
  * As always, updated translations thanks to all of the translators!
* Sun Apr 18 2021 Julian Geywitz <suse@geigi.de>
- Update to 0.9.1
  * Audiobooks are not removed from your library automatically anymore when the files cannot be found.
  * The download option will be enabled for audiobooks on removable or network drives automatically for each new storage location you add.
  * Unavailable books (books where a file can't be found) can now be opened to display the book detail view. They will be flagged with a little unavailable tag
  * Under the hood improvements in the media importer
  * Media playback is rewritten from ground up. It's far more stable than before.
  * Fix: When a different system language than English is used Cozy created two folders in the users home directory on the first startup, a translated and a English one. Now only the translated folder will be created.
  * Fix: A wrong mouse pointer was displayed with some pointer themes
  * Fix: A memory leak in the importer
  * Fix: The playback speed of a book was not remembered correctly
  * Fix: The desktop integration did not respect the switch author and reader setting
  * Fix: Setting the Playback speed did not work in v0.9
  * As always, updated translations thanks to all of the translators!
* Sun Apr 18 2021 Julian Geywitz <suse@geigi.de>
- Update to 0.9
  * Audiobooks are not removed from your library automatically anymore when the files cannot be found.
  * The download option will be enabled for audiobooks on removable or network drives automatically for each new storage location you add.
  * Unavailable books (books where a file can't be found) can now be opened to display the book detail view. They will be flagged with a little unavailable tag
  * Under the hood improvements in the media importer
  * Media playback is rewritten from ground up. It's far more stable than before.
  * Fix: When a different system language than English is used Cozy created two folders in the users home directory on the first startup, a translated and a English one. Now only the translated folder will be created.
  * Fix: A wrong mouse pointer was displayed with some pointer themes
  * Fix: A memory leak in the importer
  * Fix: The playback speed of a book was not remembered correctly
  * Fix: The desktop integration did not respect the switch author and reader setting
  * As always, updated translations thanks to all of the translators!
* Sun Jan 31 2021 Julian Geywitz <suse@geigi.de>
- Update to 0.8.1
  * A new icon! Thanks jimmac :)
  * Refined headerbar
  * A click on the cover image in the headerbar opens the book detail view
  * Book detail view: Pressing the back button on the mouse brings you back to the library
  * Fix: Aborting the download of a book is now handled more gracefully
  * Fix: Opening a book using the return key now works as expected
  * As always, updated translations thanks to all of the translators!
  * Hotfix: Custom icons where not detected
* Sun Jan 31 2021 Julian Geywitz <suse@geigi.de>
- Update to 0.8
  * A new icon! Thanks jimmac :)
  * Refined headerbar
  * A click on the cover image in the headerbar opens the book detail view
  * Book detail view: Pressing the back button on the mouse brings you back to the library
  * Fix: Aborting the download of a book is now handled more gracefully
  * Fix: Opening a book using the return key now works as expected
  * As always, updated translations thanks to all of the translators!
* Sun Dec  6 2020 Julian Geywitz <suse@geigi.de>
- Update to 0.7.8
  * Cozy is now compatible with Python 3.9 (thanks phpwutz!)
  * As always, updated translations thanks to all of the translators!
* Mon Nov 30 2020 Julian Geywitz <suse@geigi.de>
  Update to 0.7.7
  * The rewind and fast forward buttons in the desktop integration now jump 30 seconds back and forth instead of jumping a whole chapter
  * Fix: the rewind button in the toolbar is now working again
  * Fix: automatic rewind, when enabled in settings, is now working again
  * Fix: when rewinding at the beginning of a book Cozy did jump to the end of the book
  * Fix: pressing escape to leave the book detail view is now working again
  * Many other small fixes that make Cozy more reliable
  * As always, updated translations thanks to all of the translators!
* Sun Nov 22 2020 Julian Geywitz <suse@geigi.de>
  Update to 0.7.6
  * Fix: If an audiobook directory contained a lot of non audio files, Cozy could skip all other files on import (thanks foliva!)
  * Fix: When copying files via Drag and Drop sometimes the progress bar reported an incorrect progress
  * As always, updated translations thanks to all of the translators!
* Sat Nov 14 2020 Julian Geywitz <suse@geigi.de>
  Update to 0.7.5
  * Increase maximum playback speed to 3.5x
  * Fix: audio files with uppercase extensions where not detected (thanks to leuc)
  * Fix: when using drag and drop some files where not copied and imported correctly
  * Fix: removing a book from the library was sometimes not possible
  * Fix: sometimes Cozy's database ran into a locking issue, which could lead to unexpected behaviour of Cozy
  * As always, updated translations thanks to all of the translators!
* Sat Nov 14 2020 Julian Geywitz <suse@geigi.de>
  Update to 0.7.3
  * Increase maximum playback speed to 3.5x
  * Fix: audio files with uppercase extensions where not detected (thanks to leuc)
  * Fix: removing a book from the library was sometimes not possible
  * Fix: sometimes Cozy's database ran into a locking issue, which could lead to unexpected behaviour of Cozy
  * As always, updated translations thanks to all of the translators!
* Mon Sep 28 2020 Julian Geywitz <suse@geigi.de>
  Update to 0.7.2
  * Basic support for m4b audio books (chapters are not supported yet)
  * Fixed multiple bugs when using drag and drop to import files
* Thu Sep 24 2020 Julian Geywitz <suse@geigi.de>
  Update to 0.7
  * A completely rewritten and far more reliable media importer
  * Optional error reporting on crashes
  * As always, updated translations thanks to all of the translators!
* Mon Sep  7 2020 Julian Geywitz <suse@geigi.de>
  Update to 0.6.19
  * Multiple author and readers are now separated in the library view
  * Increase maximum playback speed to 3x
  * Fix: playback speed was not saved correctly under some circumstances, thanks to magnickolas
  * Updated translations thanks to all of the translators!
* Thu Jul 16 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 0.6.18:
  * Version bump
  * Fix #281: Exception when opening the book overview while
    artwork cache is not available
  * Fix #282: Removing a book produces an exception and all books
    are missing from book overview
  * Fix #278: Jump to folder is broken
  * Update build.yml
  * Revert "CI: enable debugging"
  * CI: enable debugging
  * Update extra pot
  * UÃpdate contributors
  * Update pot
  * Fix: viewport was missing in no_media stack
  * Fix #271
  * Fix: #268
  * Fix: All books where displayed in recent page
  * main_window.ui: Allow smaller window size
  * A little bit risky but should detect more mp3 files
  * track_element: bold title
  * Update magic library
  * Add elya5 to contributors
  * TrackElement: use monospace font for duration
  * Remove missing languages
  * Fix: Some legacy methods were called with the wrong book
    object
  * Update languages
  * Fix: swap author reader
  * Merge branch 'master' of github.com:geigi/cozy into
    refactor_views
  * Library-view: listen to application setting changes
  * Move filtering of author and reader to view and viewmodel
  * Observable: only notify the property name
  * WIP: a new place for application settings
  * WIP: Add player class which works with new models
  * Refactor: author reader filter box
  * Tests: remove database file at end of test
  * ...
* Tue Mar 17 2020 suse@geigi.de
- Update to 0.6.15
  * Fix: Files with missing tags failed to import
  * Updated translations
* Sun Mar  1 2020 suse@geigi.de
- Update to 0.6.14
  * A warning is displayed in the titlebar if network/external drives are not connected
  * MPRIS desktop integration is more stable
  * Fix: Last book was loaded on startup even when the storage medium was offline
  * Fix: Bugs in audiobook location settings window
  * Fix: Bug which sometimes could prevent playback of an audiobook
  * Fix: Crash which could occur on startup
  * Fix: Jumping in titlebar while dragging the position slider with long audio files
  * Updated translations
* Thu Feb 27 2020 Julian Geywitz <suse@geigi.de>
- Update to 0.6.13
  * Sleep timer: Automatic system power control
  * Updated translations
* Thu Feb 27 2020 Julian Geywitz <suse@geigi.de>
- Update to 0.6.13
  * Sleep timer: Automatic system power control
  * Updated translations
* Wed Jan 15 2020 suse@geigi.de
- Update to 0.6.12
  * Support for opus files
  * Support for diverse ogg cover art
  * Swedish translation
* Mon Jan  6 2020 Julian Geywitz <suse@geigi.de>
- Update to 0.6.11:
  * Fix: some valid media files were not detected
  * Support for python 3.8. Cheers to emmaliddell
  * Updated translations
  * Fixes in the titlebar
  * Fix: show navigation bar when searching from book overview
  * Other small fixes
* Mon Nov  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 0.6.9:
  * Remove app_menu completely
  * Version bump
  * Fix black box in icon background
* Tue Sep 17 2019 Alexei Podvalsky <avvissu@yandex.by>
- Fix error when packaging: no translations found for cozy
- Spec file cleanup
* Thu Sep 12 2019 Julian Geywitz <suse@geigi.de>
- Update to 0.6.8:
  * Cozy features a new icon! Cheers to Fatih20
  * App information is now translated! Cheers to NathanBnm
  * Updated translations
  * Fix: Sometimes the app name was not correctly displayed
* Sat Jan 12 2019 suse@geigi.de
- Update to 0.6.7:
  * Fix: Cozy crashed on startup when prefering cover image files over embedded album art
* Sat Jan 12 2019 suse@geigi.de
- Update to 0.6.6:
  * Fix: Cozy crashed on startup when prefering cover image files over embedded album art
* Mon Oct  8 2018 suse@geigi.de
- Update to 0.6.1b:
  * Fixed a bug which prevented cozy from automatically playing the next chapter
* Sat Sep  8 2018 suse@geigi.de
- Update to 0.6.1:
  * Improved artwork image quality
  * The book overview now supports multiple disks in audiobooks
  * The file not found window will only open when the file is on
    the internal drive
  * Fixed a typo
  * Support for elementaryOS 5.0
  * Updated translations
* Thu Jul 12 2018 avvissu@yandex.by
- Drop pkgconfig(granite)
* Sat Jun 23 2018 avvissu@yandex.by
- Initial package
